[![Build Status](https://travis-ci.org/scottyhq/dinosar.svg?branch=master)](https://travis-ci.org/scottyhq/dinosar)

# dinoSAR
tools for InSAR processing on AWS

## currently testing packaging and deployment tools, so the only functionality is querying ASF archive

get_inventory_asf.py -r 0.610607 1.047751 -78.195699 -77.522255
